==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/es/toolbar.py <==
# Spanish lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nuevo documento",
    "actions_accessible_name_new_document": "Nuevo documento",
    "actions_label_open": "Abrir",
    "actions_accessible_name_open": "Abrir documento",
    "actions_label_save": "Guardar",
    "actions_accessible_name_save": "Guardar documento",
    "actions_label_save_as": "Guardar como",
    "actions_accessible_name_save_as": "Guardar como copia del documento",
    "actions_label_sync": "Sincronizar",
    "actions_accessible_name_sync": "Sincronizar documento con un almacenamiento externo",
    "actions_label_edit": "Editar",
    "actions_accessible_name_edit": "Editar archivo",
    "actions_label_source": "Fuente",
    "actions_accessible_name_source": "Código fuente",
    "actions_label_encrypt": "Encriptar",
    "actions_accessible_name_encrypt": "Encriptar archivo",
    "actions_label_decrypt": "Desencriptar",
    "actions_accessible_name_decrypt": "Desencriptar archivo",
    "actions_label_bold": "Negrita",
    "actions_accessible_name_bold": "Formato de texto en negrita",
    "actions_label_italic": "Cursiva",
    "actions_accessible_name_italic": "Formato de texto en cursiva",
    "actions_label_underline": "Subrayar",
    "actions_accessible_name_underline": "Formato de texto subrayado",
    "actions_label_strikethrough": "Tachar",
    "actions_accessible_name_strikethrough": "Formato de texto tachado",
    "actions_label_blockquote": "Cita",
    "actions_accessible_name_blockquote": "Formato de texto en cita",
    "actions_label_color_picker": "Selector de color",
    "actions_accessible_name_color_picker": "Elegir un color de texto",
    "actions_label_ai_assistant": "Asistente IA",
    "actions_accessible_name_ai_assistant": "Ejecutar asistente IA",
    "actions_label_about": "Acerca de",
    "actions_accessible_name_about": "Acerca de la App",
    "actions_label_exit": "Salir",
    "actions_accessible_name_exit": "Salir de la App",
    "actions_label_settings": "Configuración",
    "actions_accessible_name_settings": "Configuración de la aplicación",

    "search_input_label": "Buscar",
    "search_input_placeholder_text": "texto en documento",
    "search_input_accessible_description": "Campo de entrada de búsqueda",
    "search_buttons_label_clear": "Limpiar búsqueda",
    "search_buttons_accessible_name_clear": "Limpiar campo de búsqueda",
    "search_buttons_label_prev": "Búsqueda anterior",
    "search_buttons_accessible_name_prev": "Resultado de búsqueda anterior",
    "search_buttons_label_next": "Búsqueda siguiente",
    "search_buttons_accessible_name_next": "Resultado de búsqueda siguiente",
    "search_case_sensitive_label": "Sensible a mayúsculas",
    "search_case_sensitive_tooltip": "Búsqueda sensible a mayúsculas",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/es/toolbar.py <==
# Spanish lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nuevo documento",
    "actions_accessible_name_new_document": "Nuevo documento",
    "actions_label_open": "Abrir",
    "actions_accessible_name_open": "Abrir documento",
    "actions_label_save": "Guardar",
    "actions_accessible_name_save": "Guardar documento",
    "actions_label_save_as": "Guardar como",
    "actions_accessible_name_save_as": "Guardar como copia del documento",
    "actions_label_sync": "Sincronizar",
    "actions_accessible_name_sync": "Sincronizar documento con un almacenamiento externo",
    "actions_label_edit": "Editar",
    "actions_accessible_name_edit": "Editar archivo",
    "actions_label_source": "Fuente",
    "actions_accessible_name_source": "Código fuente",
    "actions_label_encrypt": "Encriptar",
    "actions_accessible_name_encrypt": "Encriptar archivo",
    "actions_label_decrypt": "Desencriptar",
    "actions_accessible_name_decrypt": "Desencriptar archivo",
    "actions_label_bold": "Negrita",
    "actions_accessible_name_bold": "Formato de texto en negrita",
    "actions_label_italic": "Cursiva",
    "actions_accessible_name_italic": "Formato de texto en cursiva",
    "actions_label_underline": "Subrayar",
    "actions_accessible_name_underline": "Formato de texto subrayado",
    "actions_label_strikethrough": "Tachar",
    "actions_accessible_name_strikethrough": "Formato de texto tachado",
    "actions_label_blockquote": "Cita",
    "actions_accessible_name_blockquote": "Formato de texto en cita",
    "actions_label_color_picker": "Selector de color",
    "actions_accessible_name_color_picker": "Elegir un color de texto",
    "actions_label_ai_assistant": "Asistente IA",
    "actions_accessible_name_ai_assistant": "Ejecutar asistente IA",
    "actions_label_about": "Acerca de",
    "actions_accessible_name_about": "Acerca de la App",
    "actions_label_exit": "Salir",
    "actions_accessible_name_exit": "Salir de la App",
    "actions_label_settings": "Configuración",
    "actions_accessible_name_settings": "Configuración de la aplicación",

    "search_input_label": "Buscar",
    "search_input_placeholder_text": "Buscar texto en el documento",
    "search_input_accessible_description": "Campo de entrada de búsqueda",
    "search_buttons_label_clear": "Limpiar búsqueda",
    "search_buttons_accessible_name_clear": "Limpiar campo de búsqueda",
    "search_buttons_label_prev": "Búsqueda anterior",
    "search_buttons_accessible_name_prev": "Resultado de búsqueda anterior",
    "search_buttons_label_next": "Búsqueda siguiente",
    "search_buttons_accessible_name_next": "Resultado de búsqueda siguiente",
    "search_case_sensitive_accessible_name": "Sensible a mayúsculas",
    "search_case_sensitive_tooltip": "Búsqueda sensible a mayúsculas",
}
